==> geant4.9.4.p03.tar.gz: geant4.9.4.p03/source/processes/cuts/src/G4MCCIndexConversionTable.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: G4MCCIndexConversionTable.cc,v 1.3 2006-06-29 19:30:08 gunter Exp $
// GEANT4 tag $Name: not supported by cvs2svn $
//
// 
// ------------------------------------------------------------
//      GEANT 4 class header file
//
//
// History:
// -------
// - First implementation   20th August 2004  by H.Kurashige
//-------------------------------------

#include  "G4MCCIndexConversionTable.hh"


G4MCCIndexConversionTable::G4MCCIndexConversionTable()
{

} 

G4MCCIndexConversionTable::~G4MCCIndexConversionTable()
{
  vecNewIndex.clear();
}

void G4MCCIndexConversionTable::Reset(size_t size)
{
  // reset conversion table 
  vecNewIndex.clear();
  vecNewIndex.resize(size, -1);
}

==> geant4.10.01.p03.tar.gz: geant4.10.01.p03/source/processes/cuts/src/G4MCCIndexConversionTable.cc <==
//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: G4MCCIndexConversionTable.cc 70369 2013-05-29 14:59:24Z gcosmo $
//
// 
// ------------------------------------------------------------
//      GEANT 4 class header file
//
//
// History:
// -------
// - First implementation   20th August 2004  by H.Kurashige
//-------------------------------------

#include  "G4MCCIndexConversionTable.hh"


G4MCCIndexConversionTable::G4MCCIndexConversionTable()
{

} 

G4MCCIndexConversionTable::~G4MCCIndexConversionTable()
{
  vecNewIndex.clear();
}

void G4MCCIndexConversionTable::Reset(size_t siz)
{
  // reset conversion table 
  vecNewIndex.clear();
  vecNewIndex.resize(siz, -1);
}
